@@ -212,10 +212,11 @@ from ae.base import stack_vars
 from ae.dynamicod import try_eval                                                                         # type: ignore
 from ae.i18n import default_language, get_f_string, get_text, register_package_translations, translation  # type: ignore
 from ae.gui_app import (                                                                                  # type: ignore
-    FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
+    FLOW_KEY_SEP, EventKwargsType, MainAppBase,
+    flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs)
 
 
-__version__ = '0.3.46'
+__version__ = '0.3.47'
 
 
 register_package_translations()
@@ -704,7 +705,7 @@ class TourBase:
         main_app.vpo(f"TourBase.setup_layout(): page id={self.page_ids[self.page_idx]}")
 
         try:
-            self.top_popup = main_app.popups_opened()[-1]
+            self.top_popup = main_app.popups_opened()[0]
         except IndexError:
             self.top_popup = None
 
@@ -1138,7 +1139,7 @@ class HelpAppBase(MainAppBase, ABC):
         if self.user_id not in self.registered_users:
             self.start_app_tour()
 
-    def on_flow_popup_close(self, _flow_key: str, _event_kwargs: Dict[str, Any]) -> bool:
+    def on_flow_popup_close(self, _flow_key: str, _event_kwargs: EventKwargsType) -> bool:
         """ overwritten popup close handler of FlowPopup widget to reset help widget/text.
 
         :param _flow_key:       (unused)
